ftime

Function ftime 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn ftime(tp: *mut timeb) -> c_int
👎Deprecated
See https://pubs.opengroup.org/onlinepubs/009695399/functions/ftime.html.

Sets the time and millitm members of the timeb structure pointed to by tp to contain the seconds and milliseconds portions, respectively, of the current time in seconds since the Epoch.

Safety

The caller must ensure that tp is convertible to an Out<timeb>.

Deprecation

The ftime() function was marked as legacy in the Open Group Base Specifications Issue 6, and the entire sys/timeb.h header was removed in Issue 7.